@@ -65,4 +65,31 @@ def getLatestRevision() -> str:
     config = Config(file_=configFilePath)
     config.set_main_option("script_location", migrationsDir)
     script = ScriptDirectory.from_config(config)
+    # We expect attune-project-api to never have branches in the migration
+    # scripts, and it should be safe to assume there is only one head
     return script.get_heads()[0]
+
+
+def checkIfLibrarySupportsRevision(revision: str) -> bool:
+    """
+    Check if this version of attune-project-api supports the revision read
+    from a project. Projects can only be loaded if the project revision is
+    smaller than the highest supported version.
+
+    :param revision: Revision of project to load
+    :return: True if project can be loaded else False
+    """
+    codeDir = os.path.dirname(os.path.realpath(__file__))
+    configFilePath = os.path.join(codeDir, "alembic.ini")
+    migrationsDir = os.path.join(codeDir, "alembic_migrations")
+
+    config = Config(file_=configFilePath)
+    config.set_main_option("script_location", migrationsDir)
+    script = ScriptDirectory.from_config(config)
+
+    # We expect attune-project-api to never have branches in the migration
+    # scripts, and it should be safe to use "head" as the head
+    supportedRevisions = [
+        s.revision for s in script.walk_revisions(base="base", head="head")
+    ]
+    return revision in supportedRevisions
